@@ -9,10 +9,12 @@
 
 #include "kmbox_export.h"
 #include "mboxentry.h"
+#include <memory>
 
 #include <kmime/kmime_message.h>
 
-namespace KMBox {
+namespace KMBox
+{
 class MBoxPrivate;
 
 /**
@@ -27,12 +29,7 @@ public:
     /**
      * Describes the type of locking that will be used.
      */
-    enum LockType {
-        ProcmailLockfile,
-        MuttDotlock,
-        MuttDotlockPrivileged,
-        None
-    };
+    enum LockType { ProcmailLockfile, MuttDotlock, MuttDotlockPrivileged, None };
 
     /**
      * Creates a new mbox object.
@@ -245,8 +242,7 @@ public:
 private:
     //@cond PRIVATE
     Q_DISABLE_COPY(MBox)
-    friend class MBoxPrivate;
-    MBoxPrivate *const d;
+    std::unique_ptr<class MBoxPrivate> const d;
     //@endcond
 };
 }
